@@ -673,9 +673,56 @@ class CameraDevice(Protocol):
         | SirenState
         | BatteryState
     ): ...
+
+    @overload
     async def update_state(
-        self, state_name: str, event_data: Any, is_remote: Optional[bool] = None
+        self,
+        state_name: Literal["light"],
+        event_data: LightSetEvent,
     ) -> None: ...
+
+    @overload
+    async def update_state(
+        self,
+        state_name: Literal["motion"],
+        event_data: MotionSetEvent,
+    ) -> None: ...
+
+    @overload
+    async def update_state(
+        self,
+        state_name: Literal["audio"],
+        event_data: AudioSetEvent,
+    ) -> None: ...
+
+    @overload
+    async def update_state(
+        self,
+        state_name: Literal["object"],
+        event_data: ObjectSetEvent,
+    ) -> None: ...
+
+    @overload
+    async def update_state(
+        self,
+        state_name: Literal["doorbell"],
+        event_data: DoorbellSetEvent,
+    ) -> None: ...
+
+    @overload
+    async def update_state(
+        self,
+        state_name: Literal["siren"],
+        event_data: SirenSetEvent,
+    ) -> None: ...
+
+    @overload
+    async def update_state(
+        self,
+        state_name: Literal["battery"],
+        event_data: BatterySetEvent,
+    ) -> None: ...
+    async def update_state(self, state_name: str, event_data: Any) -> None: ...
     def on_state_change(self, state_name: StateNames) -> Observable: ...
     def on_property_change(self, property_name: str) -> Observable: ...
     def remove_all_listeners(self) -> None: ...
@@ -685,8 +732,8 @@ class CameraDevice(Protocol):
 DeviceManagerEventType = Literal[
     "cameraSelected",
     "cameraDeselected",
-    "cameraAdded",
-    "cameraRemoved",
+    # "cameraAdded",
+    # "cameraRemoved",
     "cameraUpdated",
 ]
 
@@ -713,14 +760,14 @@ class DeviceManager(Protocol):
     def on(
         self, event: Literal["cameraDeselected"], listener: CameraDeselectedCallback
     ) -> "DeviceManager": ...
-    @overload
-    def on(
-        self, event: Literal["cameraAdded"], listener: CameraAddedCallback
-    ) -> "DeviceManager": ...
-    @overload
-    def on(
-        self, event: Literal["cameraRemoved"], listener: CameraRemovedCallback
-    ) -> "DeviceManager": ...
+    # @overload
+    # def on(
+    #     self, event: Literal["cameraAdded"], listener: CameraAddedCallback
+    # ) -> "DeviceManager": ...
+    # @overload
+    # def on(
+    #     self, event: Literal["cameraRemoved"], listener: CameraRemovedCallback
+    # ) -> "DeviceManager": ...
     @overload
     def on(
         self, event: Literal["cameraUpdated"], listener: CameraUpdatedCallback
@@ -734,14 +781,14 @@ class DeviceManager(Protocol):
     def once(
         self, event: Literal["cameraDeselected"], listener: CameraDeselectedCallback
     ) -> "DeviceManager": ...
-    @overload
-    def once(
-        self, event: Literal["cameraAdded"], listener: CameraAddedCallback
-    ) -> "DeviceManager": ...
-    @overload
-    def once(
-        self, event: Literal["cameraRemoved"], listener: CameraRemovedCallback
-    ) -> "DeviceManager": ...
+    # @overload
+    # def once(
+    #     self, event: Literal["cameraAdded"], listener: CameraAddedCallback
+    # ) -> "DeviceManager": ...
+    # @overload
+    # def once(
+    #     self, event: Literal["cameraRemoved"], listener: CameraRemovedCallback
+    # ) -> "DeviceManager": ...
     @overload
     def once(
         self, event: Literal["cameraUpdated"], listener: CameraUpdatedCallback
@@ -755,14 +802,14 @@ class DeviceManager(Protocol):
     def remove_listener(
         self, event: Literal["cameraDeselected"], listener: CameraDeselectedCallback
     ) -> "DeviceManager": ...
-    @overload
-    def remove_listener(
-        self, event: Literal["cameraAdded"], listener: CameraAddedCallback
-    ) -> "DeviceManager": ...
-    @overload
-    def remove_listener(
-        self, event: Literal["cameraRemoved"], listener: CameraRemovedCallback
-    ) -> "DeviceManager": ...
+    # @overload
+    # def remove_listener(
+    #     self, event: Literal["cameraAdded"], listener: CameraAddedCallback
+    # ) -> "DeviceManager": ...
+    # @overload
+    # def remove_listener(
+    #     self, event: Literal["cameraRemoved"], listener: CameraRemovedCallback
+    # ) -> "DeviceManager": ...
     @overload
     def remove_listener(
         self, event: Literal["cameraUpdated"], listener: CameraUpdatedCallback
